@@ -3,13 +3,14 @@ __all__ = ['_']
 da = {
     'year': 'år',
     'years': 'år',
-    'mon': 'man',
-    'tue': 'tir',
-    'wed': 'ons',
-    'thu': 'tor',
-    'fri': 'fre',
-    'sat': 'lør',
-    'sun': 'søn',
+    'week': 'uge',
+    'mo': 'ma',
+    'tu': 'ti',
+    'we': 'on',
+    'th': 'to',
+    'fr': 'fr',
+    'sa': 'lø',
+    'su': 'sø',
     'may': 'maj',
     'oct': 'okt',
     'modified': 'ændret',
@@ -28,7 +29,10 @@ de = {
     'me': 'mich'}
 
 
-dictionary = None
+words = {
+    'da': {'hej', 'en', 'et', 'jeg', 'du', 'ikke', 'og', 'er', 'så'}}
+
+dictionary = {}
 
 
 def set_language(lang=None):
