@@ -3,6 +3,27 @@ if TYPE_CHECKING:
     from .document import Document  # noqa
 
 
+def str2keys(keys):
+    while keys:
+        if keys[:2] == '^^':
+            yield '^'
+            keys = keys[2:]
+        if keys[0] == '^':
+            yield keys[:2]
+            keys = keys[2:]
+        elif keys[:2] == '<<':
+            yield '<'
+            keys = keys[2:]
+        elif keys[0] == '<':
+            key, keys = keys[1:].split('>', 1)
+            yield key.replace('-', '_')
+        elif keys[0] == '\n':
+            keys = keys[1:]
+        else:
+            yield keys[0]
+            keys = keys[1:]
+
+
 class InputHandler:
     def insert_character(self, char: str) -> Optional['Document']:
         raise NotImplementedError
