@@ -1,10 +1,10 @@
 import socket
 
-from ..config import conf
+# from ..config import conf
 
 
 class MailClient:
-    def __init__(self, name: str):
+    def __init__(self, name: str, conf=None):
         self.config = conf.mail[name]
         addr = conf.home / 'mail' / name / 'socket'
         self.sock = socket.socket(socket.AF_UNIX)
@@ -12,7 +12,7 @@ class MailClient:
             self.sock.connect(str(addr))
         except FileNotFoundError:
             from .server import Server
-            Server(name).fork()
+            Server(name)
             self.sock.connect(str(addr))
 
     def get_folder(self, folder):
